# vanilla

A Pythonic wrapper around Cocoa.

Documentation is at [vanilla.robotools.dev](http://vanilla.robotools.dev/en/latest/).

Install for your own use with pip:

    $ pip install cocoa-vanilla

([RoboFont](https://robofont.com/) and [DrawBot](https://drawbot.com/) use and bundle cocoa-vanilla.)
